@@ -304,7 +304,7 @@ public class Migration {
                 ZipArchiveOutputStream destZipStream = new ZipArchiveOutputStream(CloseShieldOutputStream.wrap(dest))) {
             ZipArchiveEntry srcZipEntry;
             CRC32 crc32 = new CRC32();
-            while ((srcZipEntry = srcZipStream.getNextZipEntry()) != null) {
+            while ((srcZipEntry = srcZipStream.getNextEntry()) != null) {
                 String srcName = srcZipEntry.getName();
                 if (isSignatureFile(srcName)) {
                     logger.log(Level.WARNING, sm.getString("migration.skipSignatureFile", srcName));
@@ -413,7 +413,8 @@ public class Migration {
     }
 
     private boolean isArchive(String fileName) {
-        return fileName.endsWith(".jar") || fileName.endsWith(".war") || fileName.endsWith(".zip");
+        return fileName.endsWith(".jar") || fileName.endsWith(".war") || fileName.endsWith(".ear") ||
+                fileName.endsWith(".zip");
     }
 
 
